@@ -51,7 +51,7 @@ def grouped_l2norm(t, groups = 1):
     shape = t.shape
     dim = shape[-1]
     t = t.reshape(*shape[:-1], groups, dim // groups)
-    t = F.normalize(t, p = 2, dim = -1)
+    t = l2norm(t)
     return t.reshape(shape)
 
 def l2norm_tensors(*tensors, groups = 1):
